@@ -5,7 +5,6 @@ https://github.com/angular/angular/blob/master/CONTRIBUTING.md#-commit-message-g
 
 from __future__ import annotations
 
-import logging
 import re
 from functools import reduce
 from itertools import zip_longest
@@ -31,15 +30,13 @@ from semantic_release.commit_parser.util import (
 )
 from semantic_release.enums import LevelBump
 from semantic_release.errors import InvalidParserOptions
+from semantic_release.globals import logger
 from semantic_release.helpers import sort_numerically, text_reducer
 
 if TYPE_CHECKING:  # pragma: no cover
     from git.objects.commit import Commit
 
 
-logger = logging.getLogger(__name__)
-
-
 def _logged_parse_error(commit: Commit, error: str) -> ParseError:
     logger.debug(error)
     return ParseError(commit, error=error)
@@ -101,6 +98,10 @@ class AngularParserOptions(ParserOptions):
     parse_squash_commits: bool = False
     """Toggle flag for whether or not to parse squash commits"""
 
+    # TODO: breaking change v10, change default to True
+    ignore_merge_commits: bool = False
+    """Toggle flag for whether or not to ignore merge commits"""
+
     @property
     def tag_to_level(self) -> dict[str, LevelBump]:
         """A mapping of commit tags to the level bump they should result in."""
@@ -188,6 +189,7 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
             ),
             flags=re.MULTILINE | re.IGNORECASE,
         )
+        self.notice_selector = regexp(r"^NOTICE: (?P<notice>.+)$")
         self.filters = {
             "typo-extra-spaces": (regexp(r"(\S)  +(\S)"), r"\1 \2"),
             "git-header-commit": (
@@ -232,11 +234,18 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
     def commit_body_components_separator(
         self, accumulator: dict[str, list[str]], text: str
     ) -> dict[str, list[str]]:
-        if match := breaking_re.match(text):
-            accumulator["breaking_descriptions"].append(match.group(1) or "")
+        if (match := breaking_re.match(text)) and (brk_desc := match.group(1)):
+            accumulator["breaking_descriptions"].append(brk_desc)
             # TODO: breaking change v10, removes breaking change footers from descriptions
             # return accumulator
 
+        elif (match := self.notice_selector.match(text)) and (
+            notice := match.group("notice")
+        ):
+            accumulator["notices"].append(notice)
+            # TODO: breaking change v10, removes notice footers from descriptions
+            # return accumulator
+
         elif match := self.issue_selector.search(text):
             # if match := self.issue_selector.search(text):
             predicate = regexp(r",? and | *[,;/& ] *").sub(
@@ -252,11 +261,12 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
                     predicate.split(","),
                 )
             )
-            accumulator["linked_issues"] = sort_numerically(
-                set(accumulator["linked_issues"]).union(new_issue_refs)
-            )
-            # TODO: breaking change v10, removes resolution footers from descriptions
-            # return accumulator
+            if new_issue_refs:
+                accumulator["linked_issues"] = sort_numerically(
+                    set(accumulator["linked_issues"]).union(new_issue_refs)
+                )
+                # TODO: breaking change v10, removes resolution footers from descriptions
+                # return accumulator
 
         # Prevent appending duplicate descriptions
         if text not in accumulator["descriptions"]:
@@ -291,6 +301,7 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
             {
                 "breaking_descriptions": [],
                 "descriptions": [],
+                "notices": [],
                 "linked_issues": [],
             },
         )
@@ -311,10 +322,15 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
             scope=parsed_scope,
             descriptions=tuple(body_components["descriptions"]),
             breaking_descriptions=tuple(body_components["breaking_descriptions"]),
+            release_notices=tuple(body_components["notices"]),
             linked_issues=tuple(body_components["linked_issues"]),
             linked_merge_request=linked_merge_request,
         )
 
+    @staticmethod
+    def is_merge_commit(commit: Commit) -> bool:
+        return len(commit.parents) > 1
+
     def parse_commit(self, commit: Commit) -> ParseResult:
         if not (parsed_msg_result := self.parse_message(force_str(commit.message))):
             return _logged_parse_error(
@@ -336,6 +352,11 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
         multiple commits, each of which will be parsed separately. Single commits
         will be returned as a list of a single ParseResult.
         """
+        if self.options.ignore_merge_commits and self.is_merge_commit(commit):
+            return _logged_parse_error(
+                commit, "Ignoring merge commit: %s" % commit.hexsha[:8]
+            )
+
         separate_commits: list[Commit] = (
             self.unsquash_commit(commit)
             if self.options.parse_squash_commits
@@ -442,7 +463,7 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
             [],
         )
 
-        return separate_commit_msgs
+        return list(filter(None, separate_commit_msgs))
 
     def _find_squashed_commits_in_str(self, message: str) -> list[str]:
         separate_commit_msgs: list[str] = []
@@ -477,8 +498,4 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
 
             current_msg = clean_paragraph
 
-        # Store the last commit message (if its not empty)
-        if current_msg:
-            separate_commit_msgs.append(current_msg)
-
-        return separate_commit_msgs
+        return [*separate_commit_msgs, current_msg]
